﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;

namespace BlockDefense.Classes
{
    public class Sprite
    {
        private static int _Id = 0;
        public int Id { get; private set; }
        public Rectangle Bounds;
        public Texture2D Texture { get; protected set; }
        public Vector2 Location;
        public float Depth { get; protected set; }

        public Sprite(Texture2D texture, Vector2 location)
        {
            Id = _Id++;
            Texture = texture;
            Location = location;
            Bounds = new Rectangle((int)Location.X, (int)Location.Y, texture.Width, texture.Height); 
        }

        public Sprite(Texture2D texture, Vector2 location, float depth)
        {
            Id = _Id++;
            Texture = texture;
            Location = location;
            Depth = depth;
            Bounds = new Rectangle((int)Location.X, (int)Location.Y, texture.Width, texture.Height);
        }

        public virtual void Update(GameTime gameTime, Rectangle clientBounds)
        {
        }
        public virtual void Draw(GameTime gameTime, SpriteBatch spriteBatch)
        {
            spriteBatch.Draw(Texture, Location, null, Color.White, 0f, Vector2.Zero, 1.0f, SpriteEffects.None, Depth);
        }
        public override bool Equals(object obj)
        {
            if (obj == null)
                return false;

            Sprite s = obj as Sprite;
            if ((object)s == null)
                return false;

            return s.Id == this.Id;
        }
        public override int GetHashCode()
        {
            return Id.GetHashCode();
        }
    }
}
